@@ -133,11 +133,11 @@ sub getReads {
   }
 
   if (! defined $r1->{name} and !defined $r2->{name}) {
-    return undef;
+    return;
   } elsif (! defined $r1->{name} or !defined $r2->{name}) {
     my $r = $r1->{name} // $r2->{name};
     $self->{error} = "Premature termination, missing read mate for \"$r\"";
-    return undef;
+    return;
   }
 
   my $name_1;
@@ -201,7 +201,7 @@ FASTX::PE - A Paired-End FASTQ files reader, based on FASTX::Reader.
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 SYNOPSIS
 
