@@ -5,7 +5,7 @@ use Carp qw(confess);
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
 use File::Basename;
-$FASTX::Reader::VERSION = '1.1.0';
+$FASTX::Reader::VERSION = '1.2.0';
 require Exporter;
 our @ISA = qw(Exporter);
 #ABSTRACT: A simple module to parse FASTA and FASTQ files, supporting compressed files and paired-ends.
@@ -37,6 +37,10 @@ sub new {
     # Check if a filename was provided and not {{STDIN}}
     # uncoverable branch false
 
+    if ( defined $self->{filename} and -d $self->{filename} ) {
+      confess "Directory provide where file was expected\n";
+    }
+
     if (defined $self->{filename} and $self->{filename} ne '{{STDIN}}') {
       open my $initial_fh, '<', $self->{filename} or confess "Unable to read file ", $self->{filename}, "\n";
       read( $initial_fh, my $magic_byte, 4 );
@@ -71,6 +75,7 @@ sub new {
 
 
     } else {
+      # Filename not provided, use STDIN
       $self->{fh} = \*STDIN;
       if ($self->{loadseqs}) {
         confess("Load sequences not supported for STDIN");
@@ -96,7 +101,7 @@ sub getRead {
   #@<instrument>:<run number>:<flowcell ID>:<lane>:<tile>:<x-pos>:<y-pos>:<UMI> <read>:<is filtered>:<control number>:<index>
 
 
-  return undef if (defined $self->{status} and $self->{status} == 0);
+  return if (defined $self->{status} and $self->{status} == 0);
 
   #my $aux = $self->{aux};
   my $sequence_data;
@@ -182,11 +187,29 @@ sub getRead {
 }
 
 
+sub next {
+  my $self   = shift;
+  my $class  = "FASTX::Seq";
+  my $scalar_read = $self->getRead();
+  if (not defined $scalar_read->{seq} ) {
+    return;
+  }
+  my $seq = bless {}, $class;
+  $seq->{seq}  = $scalar_read->{seq}  // '';
+  $seq->{name}   = $scalar_read->{name}   // undef;
+  $seq->{comment} = $scalar_read->{comment} // undef;
+  $seq->{qual} = $scalar_read->{qual} // undef;
+ 
+  return $seq;
+ 
+}
+
+
 sub getFastqRead {
   my $self   = shift;
   my $seq_object = undef;
 
-  return undef if (defined $self->{status} and $self->{status} == 0);
+  return if (defined $self->{status} and $self->{status} == 0);
 
   $self->{status} = 1;
   my $header = readline($self->{fh});
@@ -202,7 +225,7 @@ sub getFastqRead {
       $self->{message} = "Unknown format: FASTQ truncated at " . $header . "?";
       $self->{status} = 0;
     }
-    return undef;
+    return;
   }
 
   # Fast format control: header and separator
@@ -244,7 +267,7 @@ sub getIlluminaRead {
   my $self   = shift;
   my $seq_object = undef;
 
-  return undef if (defined $self->{status} and $self->{status} == 0);
+  return if (defined $self->{status} and $self->{status} == 0);
 
   $self->{status} = 1;
   my $header = readline($self->{fh});
@@ -260,7 +283,7 @@ sub getIlluminaRead {
       $self->{message} = "Unknown format: FASTQ truncated at " . $header . "?";
       $self->{status} = 0;
     }
-    return undef;
+    return;
   }
 
   # Fast format control: header and separator
@@ -369,7 +392,7 @@ sub getFileFormat {
     }
   } else {
     #unknown format
-    return undef;
+    return;
   }
 }
 sub _load_seqs {
@@ -391,7 +414,7 @@ sub _load_seqs {
 
 
 sub _which {
-	return undef if ($^O eq 'MSWin32');
+	return if ($^O eq 'MSWin32');
 	my $has_which = eval { require File::Which; File::Which->import(); 1};
 	if ($has_which) {
 		foreach my $cmd (@_) {
@@ -403,7 +426,7 @@ sub _which {
 			return $cmd if (not $?);
 		}
 	}
-	return undef;
+	return;
 }
 1;
 
@@ -419,7 +442,7 @@ FASTX::Reader - A simple module to parse FASTA and FASTQ files, supporting compr
 
 =head1 VERSION
 
-version 1.1.0
+version 1.2.0
 
 =head1 SYNOPSIS
 
@@ -487,6 +510,13 @@ quality if the file is FASTQ
 
 =back
 
+=head2 next() 
+
+Get the next sequence as a blessed object, having the same attributes as 
+the regular has provided by C<getRead()>: name, comment, seq, qual.
+The class for this object is C<FASTX::Seq> and at the moment no methods 
+are available for it.
+
 =head2 getFastqRead()
 
 If the file is FASTQ, this method returns the same read object as I<getRead()> but with a simpler,
